@@ -1,12 +1,11 @@
 /****************************************************************************
 **
-*W  compiler.h                  GAP source                   Ferenc Ràkòczi
-*W                                                         & Martin Schönert
+**  This file is part of GAP, a system for computational discrete algebra.
 **
+**  Copyright of GAP belongs to its developers, whose names are too numerous
+**  to list here. Please refer to the COPYRIGHT file for details.
 **
-*Y  Copyright (C)  1997,  Lehrstuhl D für Mathematik,  RWTH Aachen,  Germany
-*Y  (C) 1998 School Math and Comp. Sci., University of St Andrews, Scotland
-*Y  Copyright (C) 2002 The GAP Group
+**  SPDX-License-Identifier: GPL-2.0-or-later
 **
 **  This file declares the functions of the GAP to C compiler.
 */
@@ -20,12 +19,7 @@
 **
 *F  CompileFunc(<output>,<func>,<name>,<magic1>,<magic2>) . . . . . . compile
 */
-extern Int CompileFunc (
-            Obj                 output,
-            Obj                 func,
-            Obj                 name,
-            Int                 magic1,
-            Obj                 magic2 );
+Int CompileFunc(Obj output, Obj func, Obj name, Int magic1, Obj magic2);
 
 
 /****************************************************************************
